@@ -21,7 +21,7 @@ from .shortcuts import (
 from .unittest import TestCaseMixin, disable_elastic_apm, disable_migration, disable_network, fake_time
 from .validators import is_chinese_phone, is_int, is_phone, is_singapore_phone, is_uuid
 
-__version__ = "1.0.7"
+__version__ = "1.0.8"
 
 __all__ = [
     "EmptyContextManager",
@@ -64,7 +64,7 @@ __all__ = [
 
 try:
     from .django.apis import Errors, check_error, get_validation_error, get_object_or_error  # NOQA
-    from .django.databases import DynamicField, HManager, HQuerySet, ModelMixin  # NOQA
+    from .django.databases import DynamicField, ExtendModelMixin, HManager, HQuerySet, ModelMixin  # NOQA
     from .django.migrations import AlterDefault  # NOQA
     from .django.unittest import extend_django_sqlite  # NOQA
 
@@ -73,6 +73,7 @@ try:
             "AlterDefault",
             "DynamicField",
             "Errors",
+            "ExtendModelMixin",
             "HManager",
             "HQuerySet",
             "ModelMixin",
@@ -84,14 +85,3 @@ try:
     )
 except ImportError:
     pass
-
-
-try:
-    from .grpc.servicers import GrpcMetaclass, register_servicer_command  # NOQA
-    from .grpc.unittest import FakeChannel, FakeContext, FakeRpcError, FakeServer  # NOQA
-
-    __all__.extend(
-        ["FakeChannel", "FakeContext", "FakeRpcError", "FakeServer", "GrpcMetaclass", "register_servicer_command"]
-    )
-except ImportError:
-    pass
